/**
 * Copyright (C) 2021 fortiss GmbH
 * @author Erkan Karabulut – "karabulut@fortiss.org"
 * @version 1.2
 * Bottom navigation component UI and functionalities
 */

import React from 'react';
import {View, Image, TouchableOpacity} from 'react-native';
import {connect} from 'react-redux';
import EStyleSheet from 'react-native-extended-stylesheet';
import * as Colors from '../constant/string/Colors';

/**
 * @file Bottom navigation component
 */
class BottomNavigation extends React.Component {
    constructor(props) {
        super(props);
        this.state = {};
    }

    componentDidMount() {
    }

    render() {
        return (
            <View style={this.props.style}>
                <View style={styles.bottomNavigation}>
                    <View style={styles.navigationItem}>
                        <TouchableOpacity onPress={() => this.props.navigation.navigate('Home')}>
                            <Image source={require("../asset/image/home.png")} style={styles.navigationIcon}/>
                        </TouchableOpacity>
                    </View>
                    <View style={styles.navigationItem}>
                        <TouchableOpacity onPress={() => this.props.navigation.navigate('Describe')}>
                            <Image source={require("../asset/image/describe.png")} style={styles.navigationIcon}/>
                        </TouchableOpacity>
                    </View>
                    <View style={styles.navigationItem}>
                        <TouchableOpacity onPress={() => this.props.navigation.navigate('Updates')}>
                            <Image source={require("../asset/image/graph.png")} style={styles.navigationIcon}/>
                        </TouchableOpacity>
                    </View>
                </View>
            </View>
        );
    }
}

// CSS styles
let styles = EStyleSheet.create({
    bottomNavigation: {
        borderTopColor: 'black',
        flexDirection: 'row',
        justifyContent: 'center',
        alignItems: 'center',
        borderTopWidth: 1,
        backgroundColor: Colors.blue
    },
    navigationItem: {
        marginHorizontal: "40rem",
        marginVertical: "10rem",
        flexDirection: 'column',
        justifyContent: "center",
        alignItems: "center",
        height:"30rem"
    },
    navigationIcon: {
        backgroundColor: "white",
        width: "40rem",
        height: "40rem",
        borderRadius: "30rem"
    }
});

/**
 * map states to redux props
 */
const mapStateToProps = (state) => ({
    messages: state.language.messages,
});

const mapDispatchToProps = {};

/**
 * connect to react redux redux
 */
export default connect(mapStateToProps, mapDispatchToProps)(BottomNavigation);
