/**
 * Copyright (C) 2021 fortiss GmbH
 * @author Erkan Karabulut – "karabulut@fortiss.org"
 * @version 1.2
 * Main react native component of the mobile app
 */

import React from 'react';
import store from './store'
import {Provider} from 'react-redux';
import AppNavigation from '../config/navigation';
import SplashScreen from 'react-native-splash-screen'
import LocalStorageService from "../service/LocalStorageService";

/**
 * Main React component
 */
export default class App extends React.Component {
    componentDidMount() {
        // do stuff while splash screen is shown
        // After having done stuff (such as async tasks) hide the splash screen

        // load data from local storage
        LocalStorageService.loadDataFromLocalStorage();
        // subscribe to store changes to save them locally
        store.subscribe(() => {
            LocalStorageService.storeStateIntoLocalStorage();
        });

        SplashScreen.hide();
    }

    render() {
        return (
            <Provider store={store}>
                <AppNavigation/>
            </Provider>
        );
    }
}

