/**
 * Copyright (C) 2021 fortiss GmbH
 * @author Erkan Karabulut – "karabulut@fortiss.org"
 * @version 1.2
 * Constant parameters of the app
 */

import store from "../config/store";

/**
 * Store app-wide constants and constants-related operations
 */
export default class Constants {
    // default constants
    static constants = {
        BROKER_URL: "10.0.33.39",
        BROKER_PORT: 9001,
        BROKER_USERNAME: "tsmatchdemouser",
        BROKER_PASSWORD: "tsmatchdemouser",
        DISCOVERY_TOPIC: "fortiss-org.TSMATCH.NDATA.DISCOVERY",
        DEADVERTISE_TOPIC: "fortiss-org.TSMATCH.NDATA.DEADVERTIZE",
        OBSERVATION_REQUEST_TOPIC: "fortiss-org.TSMATCH.NDATA.SERVICE_REQUEST",
        RESPONSE_TOPIC: "fortiss-org.TSMATCH.NDATA.SERVICE_RESPONSE",
        DELETE_REQUEST_TOPIC: "fortiss-org.TSMATCH.NDATA.DELETE_SERVICE_REQUEST",
        OBSERVATION_TOPIC: "fortiss-org.TSMATCH.NDATA.OBSERVATION",
        DISCOVERY_ALL_TOPIC: "fortiss-org.TSMATCH.NDATA.REQUEST_DISCOVERY_ALL",
        DISCOVERY_ALL_RESPONSE_TOPIC: "fortiss-org.TSMATCH.NDATA.RESPONSE_DISCOVERY_ALL",
        CREATOR_ID: "FORTISS_IIOTLAB_MOBILE_APP",
        version: "2.0.0"
    };

    /**
     * Update constants with the given new values
     * @param newConstants
     */
    static updateConstants(newConstants) {
        Object.keys(newConstants).map((constant) => {
            if (constant !== "version") {
                this.constants[constant] = newConstants[constant];
            }
        });

        store.dispatch({type: "UPDATE_CONSTANTS", constants: this.constants})
    }

    static switchToEFPF() {
        let efpfConfig = {
            BROKER_URL: "efpf.smecluster.com",
            BROKER_PORT: 9001,
            BROKER_USERNAME: "username",
            BROKER_PASSWORD: "password",
        };

        this.updateConstants(efpfConfig);
    }

    static switchToIIoTLab() {
        let iiotLabConfig = {
            BROKER_URL: "10.0.33.39",
            BROKER_PORT: 9001,
            BROKER_USERNAME: "tsmatchdemouser",
            BROKER_PASSWORD: "tsmatchdemouser",
        };

        this.updateConstants(iiotLabConfig);
    }
}
