/**
 * Copyright (C) 2021 fortiss GmbH
 * @author Erkan Karabulut – "karabulut@fortiss.org"
 * @version 1.2
 * Service request's response related operations on react-redux storage
 */

const initialState = {
    responseList: []
}

/**
 * Response storage operations on react redux
 * @param state
 * @param action
 * @returns {{responseList: []}}
 */
const response = (state = initialState, action) => {
    switch (action.type) {
        case 'ADD_RESPONSE':
            let exists = false;
            state.responseList.forEach(function (response) {
                if (JSON.stringify(response) === JSON.stringify(action.response)) {
                    exists = true;
                }
            });
            if (!exists) {
                state.responseList.push(action.response);
            }
            break;
        case 'REMOVE_RESPONSE':
            state.responseList.forEach(function (response) {
                if (JSON.stringify(response) === JSON.stringify(action.response)) {
                    state.responseList.splice(state.responseList.indexOf(response), 1);
                }
            });
            break;
        case 'REMOVE_SENSOR_FROM_RESPONSE':
            state.responseList.forEach(function (response) {
                if (JSON.stringify(response) === JSON.stringify(action.response)) {
                    state.responseList.splice(state.responseList.indexOf(response), 1);
                    Object.keys(response.grouping).forEach(requestId => {
                        Object.keys(response.grouping[requestId]).forEach(aggregationId => {
                            response.grouping[requestId][aggregationId].forEach(sensorId => {
                                if (sensorId === action.sensorId) {
                                    response.grouping[requestId][aggregationId].splice(
                                        response.grouping[requestId][aggregationId].indexOf(sensorId), 1
                                    );
                                }
                            });
                        });
                    });

                    state.responseList.push(response);
                }
            });

            break;

        case 'REMOVE_REQUEST_FROM_RESPONSE':
            state.responseList.forEach(response => {
                if (response && response.grouping) {
                    Object.keys(response.grouping).forEach(requestId => {
                        if (requestId === action.requestId) {
                            state.responseList.splice(state.responseList.indexOf(response), 1);
                            delete response.grouping[requestId];
                            if (Object.keys(response.grouping).length !== 0) {
                                state.responseList.push(response);
                            }
                        }
                    })
                }
            })
            break;
    }

    return {responseList: state.responseList};
}

export default response;

