/**
 * Copyright (C) 2021 fortiss GmbH
 * @author Erkan Karabulut – "karabulut@fortiss.org"
 * @version 1.2
 * This file includes service request result page's UI and logic parts
 */

import React from 'react';
import {
    View,
    Text,
    SafeAreaView,
    TouchableOpacity,
    FlatList
} from 'react-native';
import {connect} from 'react-redux';
import EStyleSheet from 'react-native-extended-stylesheet';
import BottomNavigation from "../component/BottomNavigation";
import * as Colors from '../constant/string/Colors';

/**
 * Service requests' result page
 */
class AspectInsertResult extends React.Component {
    constructor(props) {
        super(props);
        this.state = {};
    }

    render() {
        // Result of the describe request is sent from the previous describe page
        const params = this.props.route.params;

        // Create a list containing describe request results
        let responseView = [];
        let incrementalResultKey = 1;
        if (params.resultList) {
            for (let result of params.resultList) {
                let monitoredAspect = [];
                let nonMatchedLocation = [];
                if (result.aspectInsertResult) {
                    // create indentation
                    monitoredAspect.push(result.type + " " + this.props.messages.isMonitored);
                    monitoredAspect.push("\t" + result.function);
                    for (let sensor in result.sensors) {
                        monitoredAspect.push("\t\t" + result.sensors[sensor]);
                    }
                } else {
                    monitoredAspect.push(result.type + " " + this.props.messages.isNotMonitored);
                    monitoredAspect.push("\t" + result.error);
                }

                if (result.nonMatchedLocations && result.nonMatchedLocations.length > 0) {
                    nonMatchedLocation.push(this.props.messages.nonMatchedLocations);
                    result.nonMatchedLocations.forEach(location => {
                        let locationText = "\t" + location.building.name + ": " + location.building.address + ", Floor: " +
                            location.floor + ", Room: " + location.room;
                        nonMatchedLocation.push(locationText);
                    });
                }

                responseView.push(
                    <View key={incrementalResultKey}>
                        <Text style={styles.successfulAspectMonitoring}>
                            {result.aspectInsertResult ? this.props.messages.successfulAspectMonitoring :
                                this.props.messages.unSuccessfulAspectMonitoring}
                        </Text>
                        <FlatList data={monitoredAspect}
                                  keyExtractor={(item, index) => index.toString()}
                                  renderItem={({item, index}) => (
                                      <View style={styles.listView}>
                                          <Text style={index === 0 ? styles.listHeader : styles.listContent}>
                                              {item}
                                          </Text>
                                      </View>)}/>

                        <FlatList data={nonMatchedLocation}
                                  keyExtractor={(item, index) => index.toString()}
                                  renderItem={({item, index}) => (
                                      <View style={styles.listView}>
                                          <Text style={index === 0 ? styles.listHeader : styles.listContent}>
                                              {item}
                                          </Text>
                                      </View>)}/>
                    </View>
                )

                incrementalResultKey++;
            }
        }

        return (
            <SafeAreaView style={styles.container}>
                <Text style={styles.describe}>
                    {this.props.messages.describe}
                </Text>
                <View style={styles.resultsView}>
                    {responseView}
                </View>
                {
                    <TouchableOpacity style={styles.tryAgainButton}
                                      onPress={() => this.props.navigation.navigate('Describe')}>
                        <Text style={styles.tryAgainButtonText}>{this.props.messages.ok}</Text>
                    </TouchableOpacity>
                }
                <View style={{flex: 7}}/>
                <BottomNavigation navigation={this.props.navigation}/>
            </SafeAreaView>
        );
    }
}

// CSS Style
let styles = EStyleSheet.create({
    container: {
        flex: 10,
        backgroundColor: "#FFF"
    },
    describe: {
        textAlign: 'center',
        margin: '10rem',
        fontSize: '40rem',
        fontWeight: 'bold',
        color: Colors.blue
    },
    resultsView: {
        marginTop: "10rem"
    },
    successfulAspectMonitoring: {
        flex: 0.5,
        marginLeft: "15rem",
        fontWeight: 'bold',
        fontSize: '16rem',
        textAlign: "center",
        marginBottom: "20rem",
        color: Colors.blue
    },
    listHeader: {
        color: "white",
        backgroundColor: Colors.blue
    },
    listContent: {
        fontSize: "12rem",
        color: Colors.blue
    },
    listView: {
        marginHorizontal: "15rem",
        borderWidth: "1rem",
        borderColor: Colors.blue,
        backgroundColor: Colors.light_blue,
        color: Colors.blue
    },
    tryAgainButton: {
        borderWidth: "1rem",
        borderRadius: "5rem",
        borderColor: Colors.blue,
        backgroundColor: Colors.light_blue,
        width: "80rem",
        height: "30rem",
        alignItems: "center",
        justifyContent: "center",
        alignSelf: "flex-end",
        marginRight: "15rem",
        marginTop: "30rem"
    },
    tryAgainButtonText: {
        color: Colors.blue,
        fontSize: "12rem"
    }
});

// Connect to react redux
const mapStateToProps = (state) => ({
    messages: state.language.messages,
});

const mapDispatchToProps = {};

export default connect(mapStateToProps, mapDispatchToProps)(AspectInsertResult);
