/**
 * Copyright (C) 2021 fortiss GmbH
 * @author Erkan Karabulut – "karabulut@fortiss.org"
 * @version 1.2
 * This file contains some common utilities of measurement aspects
 */

import store from "../config/store";

/**
 * Common utilities of service request and responses
 */
export default class AspectService {
    /**
     * Find a response object from the given list by it's id
     * @param requestId
     * @param responseList
     * @returns {null}
     */
    static findResponseByRequestId(requestId, responseList) {
        let searchedResponse = null;
        responseList.forEach((response) => {
            if (response && response.grouping) {
                Object.keys(response.grouping).forEach(key => {
                    if (key === requestId) {
                        searchedResponse = response;
                    }
                });
            }
        })

        return searchedResponse;
    }

    /**
     *Find a request from the given request list by it's id
     * @param requestId
     * @param requestList
     * @returns {null}
     */
    static findRequestById(requestId, requestList) {
        let searchedRequest = null;
        requestList.forEach((request) => {
            if (request.uuid === requestId) {
                searchedRequest = request;
            }
        })

        return searchedRequest;
    }

    /**
     * Extract response from the given payload and store it in react redux
     * @param payload
     * @param requestList
     */

    static storeResponse(payload, requestList) {

        if (Object.keys(payload).length === 0) {
            console.log("Empty response arrived: ", payload);
            return;
        }

        if (payload.grouping) {
            for (let request of requestList) {
                if (Object.keys(payload.grouping).includes(request.uuid)) {
                    store.dispatch({type: "ADD_RESPONSE", response: payload})
                }
            }
        } else if (payload.requestId) {
            for (let request of requestList) {
                if (payload.requestId === request.uuid) {
                    store.dispatch({type: "ADD_RESPONSE", response: payload})
                }
            }
        }
    }
}
