/**
 * Copyright (C) 2021 fortiss GmbH
 * @author Erkan Karabulut – "karabulut@fortiss.org"
 * @version 1.2
 * Includes device/sensor related common operations
 */

import React from "react";
import Entypo from "react-native-vector-icons/Entypo";
import Ionicons from "react-native-vector-icons/Ionicons";
import MaterialCommunityIcons from "react-native-vector-icons/MaterialCommunityIcons";
import store from "../config/store";
import * as Colors from '../constant/string/Colors';

/**
 * This class contains common utilities of devices/sensors' and related objects
 */
export default class DeviceService {
    /**
     * Create an icon for specific sensors/devices
     * @param name
     * @returns {JSX.Element}
     */
    static getDeviceIconByType(name) {
        if (name.toLowerCase().includes("temperature")) {
            return <Entypo color={Colors.blue} name="thermometer" size={50}/>;
        } else if (name.toLowerCase().includes("humidity")) {
            return <Entypo color={Colors.blue} name="water" size={50}/>;
        } else if (name.toLowerCase().includes("sound")) {
            return <Entypo color={Colors.blue} name="sound" size={50}/>;
        } else if (name.toLowerCase().includes("co2")) {
            return <Entypo color={Colors.blue} name="air" size={50}/>;
        } else if (name.toLowerCase().includes("particulate")) {
            return <MaterialCommunityIcons color={Colors.blue} name="air-filter" size={50}/>
        } else if (name.toLowerCase().includes("occupancy")) {
            return <Ionicons color={Colors.blue} name="people" size={50}/>
        } else {
            return <Entypo name="help" size={50}/>;
        }
    }

    /**
     * Extract location string from a device object and formats it
     * @param device
     * @returns {string}
     */
    static getLocationTextFromDeviceDefinition(device) {
        let locationString = "";

        locationString += "Building: " + device.location.building.name + ": " + device.location.building.address;
        locationString += " Floor: " + device.location.floor;
        locationString += " Room: " + device.location.room;

        return locationString;
    }

    /**
     * Store a given device into react redux storage
     * @param payload
     */
    static storeDevice(payload) {
        // check if the advertised device exists in react redux
        for (let i = 0; i < store.getState().device.deviceList.length; i++) {
            if (store.getState().device.deviceList[i].objectId === payload.sensor.objectId) {
                return;
            }
        }

        console.log("New sensor discovered: ", payload.sensor.name, " - ", payload.sensor.objectId);
        // store device in react redux
        const device = {
            name: payload.sensor.name,
            thing: payload.sensor.thing_name,
            location: payload.location,
            unit: payload.sensor.unitOfMeasurement_name,
            description: payload.sensor.description,
            objectId: payload.sensor.objectId,
            parentObjectId: payload.sensor.thing_objectId
        };

        store.dispatch({type: "ADD_DEVICE", device: device});
    }
}
