/**
 * Copyright (C) 2021 fortiss GmbH
 * @author Erkan Karabulut – "karabulut@fortiss.org"
 * @version 1.2
 * This file contains the functions that interacts with local storage of the device
 */

import store from "../config/store";
import AsyncStorage from "@react-native-async-storage/async-storage";
import MQTTClientService from "./MQTTClientService";
import Constants from "../constant/constants";

/**
 * This class is used to store/restore data from local storage
 */
export default class LocalStorageService {
    /**
     * Get latest react redux storage and store locally the ones that we are interested
     */
    static storeStateIntoLocalStorage() {
        let currentState = store.getState();
        AsyncStorage.setItem("store", JSON.stringify({
            "requestList": currentState.request.requestList,
            "responseList": currentState.response.responseList,
            "constants": currentState.constants.constantsObject
        }));
    }

    /**
     * Load data from local storage into react redux
     */
    static loadDataFromLocalStorage() {
        AsyncStorage.getItem("store").then((oldStore) => {
            if (oldStore && oldStore.length) {
                let oldStoreObject = JSON.parse(oldStore);
                oldStoreObject.requestList.forEach((request) => {
                    store.dispatch({type: "ADD_REQUEST", request: request});
                });
                oldStoreObject.responseList.forEach((response) => {
                    store.dispatch({type: "ADD_RESPONSE", response: response});
                });
                store.dispatch({type: "UPDATE_CONSTANTS", constants: oldStoreObject.constants});
            }
            MQTTClientService.connect();
        });
    }
}
