/**
* MIT License
*
* Copyright (c) 2020 fortiss GmbH
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in all
* copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
* 
* SPDX-License-Identifier: MIT
* @author Nisrine Bnouhanna 
* @version 1.0
 * Includes common coaty events
 */

import {DatabaseChange, modelTypes, ObservationResults} from "../shared/models";
import {AdvertiseEvent} from "@coaty/core";

/**
 * Common coaty events
 */
export class Events {
    // Publish an DB change of the newly created grouping
    public static _advertiseDatabaseChange(communicationManager, eventId) {
        const change: DatabaseChange = {
            name: "GROUPING_CHANGED",
            objectId: eventId,
            objectType: modelTypes.OBJECT_TYPE_DATABASE_CHANGE,
            coreType: "CoatyObject",
            hasLogChanged: true,
            hasTaskChanged: true,
        };
        communicationManager.publishAdvertise(AdvertiseEvent.withObject(change));
    }

    public static _advertiseGroupingOnRestart(communicationManager, eventId) {
        const change: DatabaseChange = {
            name: "GROUPING_CHANGED",
            objectId: eventId,
            objectType: modelTypes.OBJECT_TYPE_DATABASE_CHANGE,
            coreType: "CoatyObject",
            hasLogChanged: false,
            hasTaskChanged: false,
        };
        communicationManager.publishAdvertise(AdvertiseEvent.withObject(change));
    }

    // advertize observation values
    public static _advertiseAverageObsResults(communicationManager, eventId, grouping, observationResults, timestamp) {
        const obs: ObservationResults = {
            name: "observationResults",
            objectId: eventId,
            objectType: modelTypes.OBJECT_TYPE_OBSERVATION_RESULTS,
            coreType: "CoatyObject",
            grouping: grouping,
            results: observationResults,
            timestamp: timestamp,
        };

        communicationManager.publishAdvertise(AdvertiseEvent.withObject(obs));
    }
}
