/**
* MIT License
*
* Copyright (c) 2020 fortiss GmbH
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in all
* copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
* 
* SPDX-License-Identifier: MIT
* @author Nisrine Bnouhanna
* @version 1.0
 * config file of the coaty conatiner for the TSMatch Engine
 * Uses coatyio Siemens AG. Licensed under the MIT License
 */


import {AgentInfo, Configuration} from "@coaty/core";
import {NodeUtils} from "@coaty/core/runtime-node";

NodeUtils.logInfo(`BROKER_URL=${process.env.BROKER_URL}`);

if (!process.env.BROKER_URL) {
    NodeUtils.logError(new Error("Missing Broker URL"), "Environment variable BROKER_URL not specified.");
    process.exit(1);
}

if (!process.env.NEO4J_HOST) {
    NodeUtils.logError(new Error("Missing Database URL"), "Environment variable NEO4J_HOST not specified.");
    process.exit(1);
}

/**
 * Gets common Configuration object for Hello World service and monitor
 * components.
 *
 * @param agentInfo the component's agent info
 */
export function serviceConfig(agentInfo: AgentInfo, agentName: string): Configuration {
    return {
        common: {
            agentInfo,
            agentIdentity: {name: agentName},
        },
        communication: {
            brokerUrl: process.env.BROKER_URL,
            mqttClientOptions: {
                username: process.env.BROKER_USERNAME,
                password: process.env.BROKER_PASSWORD,
            },
            namespace: "coaty.demonstrator2",
            shouldAutoStart: true,
        },
        databases: {
            neo4j: {
                adapter: "Neo4jAdapter",
                connectionString: `bolt://${process.env.NEO4J_HOST}:${process.env.NEO4J_PORT}`,
                connectionOptions: {
                    NEO4J_USERNAME: process.env.NEO4J_USERNAME,
                    NEO4J_PASSWORD: process.env.NEO4J_PASSWORD,
                    NEO4J_DATABASE: process.env.NEO4J_DATABASE,
                }
            }
        },
    };
}
