/**
* MIT License
*
* Copyright (c) 2020 fortiss GmbH
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in all
* copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
* 
* SPDX-License-Identifier: MIT
* @author Nisrine Bnouhanna 
* @version 1.0
 * DB configuration
 * Uses coatyio Siemens AG. Licensed under the MIT License
 */

import {DatabaseOptions} from "@coaty/core";
import {DbAdapterFactory, DbContext} from "@coaty/core/db";
import {PostgresAdapter} from "@coaty/core/db/adapter-postgres";

export class Db {

    public static readonly COLLECTION_SENSOR = "sensor";
    public static readonly COLLECTION_SERIVICE = "service";
    public static readonly COLLECTION_THING = "thing";
    public static readonly COLLECTION_FEATURE = "feature";
    public static readonly COLLECTION_GROUPING = "grouping";
    public static readonly COLLECTION_REQUEST = "request";

    private static readonly DB_HOST = process.env.DB_HOST;
    private static readonly DB_PORT = process.env.DB_PORT;
    private static readonly DB_NAME = process.env.DB_NAME;
    private static readonly DB_USERNAME = process.env.DB_USERNAME;
    private static readonly DB_PASSWORD = process.env.DB_PASSWORD;
    private static readonly DB_ADMIN_USERNAME = process.env.DB_ADMIN_USERNAME;
    private static readonly DB_ADMIN_PASSWORD = process.env.DB_ADMIN_PASSWORD;

    public static getConnectionString() {
        return `postgres://${this.DB_USERNAME}:${this.DB_PASSWORD}@${this.DB_HOST}:${this.DB_PORT}/${Db.DB_NAME}`;
    }

    public static getAdminConnectionString() {
        return `postgres://${this.DB_ADMIN_USERNAME}:${this.DB_ADMIN_PASSWORD}@${this.DB_HOST}:${this.DB_PORT}/${Db.DB_NAME}`;
    }

    public static initDatabaseAdapters() {
        DbAdapterFactory.registerAdapter("PostgresAdapter", PostgresAdapter);
    }

    /**
     * Set up the Postgres database by creating a database user and a database
     * with two collections for logs and tasks.
     *
     * @param options Database options
     * @param clearData if true, clear all collection data from previous runs
     */
    public static initDatabase(options: DatabaseOptions, clearData: boolean = true): Promise<any> {
        // tslint:disable-next-line: no-string-literal
        const dbcAdmin = new DbContext(options["admindb"]);

        return dbcAdmin.callExtension("initDatabase",
            // tslint:disable-next-line: no-string-literal
            options["db"],
            // tslint:disable-next-line: max-line-length
            [Db.COLLECTION_SENSOR, Db.COLLECTION_FEATURE, Db.COLLECTION_THING, Db.COLLECTION_SERIVICE, Db.COLLECTION_GROUPING, Db.COLLECTION_REQUEST], clearData);
    }
}
