﻿/**
* MIT License
*
* Copyright (c) 2020 fortiss GmbH
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in all
* copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
* 
* SPDX-License-Identifier: MIT
* @author Nisrine Bnouhanna 
* @version 1.0
 * specifies the shared models used by the coaty container: the service request and the observation results
 * Uses coatyio Siemens AG. Licensed under the MIT License
 */

import { CoatyObject, Task } from "@coaty/core";

export const modelTypes = {
    OBJECT_TYPE_SERVICE_DESCRIPTION: "coaty.sensorthings.ServiceDescription",
    OBJECT_TYPE_DATABASE_CHANGE: "coaty.DatabaseChange",
    OBJECT_TYPE_OBSERVATION_RESULTS: "coaty.sensorthings.Observationresults",
    OBJECT_TYPE_GROUPING: "coaty.SensorGrouping",
};

/**
 * Represents a service request.
 */
export interface ServiceTaskRequest extends Task {

    urgency: ServieTaskRequestPriority;
    FeatureOfInterest: any;
    unitOfMeasurement: any;
    threshold: any;
    Location: any;
    MQTTtopic: any;
    domain: string;
    domainDetail: string;
    monitoringAspect: string;
    monitoringAspectDetail: string;
}

export enum ServieTaskRequestPriority {
    Low,
    Medium,
    High,
    Critical,
}

export interface ObservationResults extends CoatyObject {
    grouping: any;
    results: number;
    timestamp: number;
}
export interface DatabaseChange extends CoatyObject {

    /**
     * Indicates that a new log object has been written to the database (optional).
     * If not specified, the default value is false.
     */
    hasLogChanged?: boolean;

    /**
     * Indicates that a new task has written to the database (optional).
     * If not specified, the default value is false.
     */
    hasTaskChanged?: boolean;
}
