/**
* MIT License
*
* Copyright (c) 2020 fortiss GmbH
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in all
* copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
* 
* SPDX-License-Identifier: MIT
* @author Erkan Karabulut 
* @version 1.0
* Includes common graphdb operations
*/

import {DbAdapterFactory, DbContext} from "@coaty/core/db";
import {Neo4jAdapter} from "../Neo4jAdapter";
import {DatabaseOptions, ObjectCacheController} from "@coaty/core";
import {ServiceTaskRequest} from "../models";

/**
 * Common db operations
 */
export class BaseRepository extends ObjectCacheController<ServiceTaskRequest> {
    public dbContext;

    /**
     * register the neo4j db adapter to coaty
     */
    static registerDBAdapter() {
        DbAdapterFactory.registerAdapter("Neo4jAdapter", Neo4jAdapter);
    }

    /**
     * Initialize the neo4j db
     * @param options
     */
    static initializeDatabase(options: DatabaseOptions) {
        const dbContext = new DbContext(options["neo4j"]);
        return dbContext.callExtension("initDatabase", options["neo4j"]);
    }
}
