/**
* MIT License
*
* Copyright (c) 2020 fortiss GmbH
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in all
* copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
* 
* SPDX-License-Identifier: MIT
* @author Erkan Karabulut 
* @version 1.0
 * Db operations related with the sensor ontology
 */

import {DbContext} from "@coaty/core/db";

/**
 * Db operations related with the sensor ontology
 */
export class OntologyRepository {
    /**
     * Get the array of similar words for a given node list
     * @param ontologyNodeList
     * @param dbContext
     */
    public static getListOfSynonyms(ontologyNodeList, dbContext: DbContext): Promise<any> {
        return dbContext.callExtension("runQuery",
            `match (s:Ontology) where any(item in $ontologyNodeList where item = s.name)
            return s.name, s.synonyms`, {
                ontologyNodeList: ontologyNodeList
            });
    }

    public static getAggregationPoints(dbContext: DbContext) {
        return dbContext.callExtension("runQuery",
            "match (o:Ontology {aggregationPoint: True}) return o"
        )
    }
}
