/**
* MIT License
*
* Copyright (c) 2020 fortiss GmbH
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in all
* copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
* 
* SPDX-License-Identifier: MIT
* @author Erkan Karabulut 
* @version 1.0
 * DB operations related service requests
 */

import {DbContext} from "@coaty/core/db";

/**
 * Service request related service requests
 */
export class RequestRepository {

    /**
     * Insert a given request to the db
     * @param dbContext
     * @param request
     */
    static insertRequest(dbContext: DbContext, request: {}) {
        // mark the request as not processed yet
        request["responseSent"] = false;
        request["isProcessed"] = false;
        return dbContext.callExtension("runQuery",
            `with apoc.convert.fromJsonMap($request) as requestObject
            create (r:Request)
            set r=requestObject`, {
                request: JSON.stringify(request)
            }
        );
    }

    /**
     * Delete a request by ID and also the relations(edges) of it
     * @param dbContext
     * @param requestId
     */
    static deleteRequest(dbContext: DbContext, requestId) {
        return dbContext.callExtension("runQuery",
            `match (t)-[rel]-(r:Request {objectId: $objectId})
            delete rel,r`, {
                objectId: requestId
            });
    }

    /**
     * get a list of requests
     * @param dbContext
     */
    static getAllRequests(dbContext: DbContext) {
        return dbContext.callExtension("runQuery",
            `match (r:Request) return (r)`);
    }
}
