/**
* MIT License
*
* Copyright (c) 2020 fortiss GmbH
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in all
* copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
* 
* SPDX-License-Identifier: MIT
* @author Erkan Karabulut 
* @version 1.0
 * DB operations related with IoT things
 */

import {DbContext} from "@coaty/core/db";

/**
 * DB operations related with IoT things
 */
export class ThingRepository {
    public static getIoTThingByObjectId(dbContext: DbContext, objectId: string) {
        return dbContext.callExtension("runQuery",
            `match (t:Thing {objectId: $objectId}) return t`, {
                objectId: objectId
            });
    }

    public static getSensorByParentObjectId(dbContext: DbContext, parentObjectId: string) {
        return dbContext.callExtension("runQuery",
            `match (s:Sensor {parentObjectId: $parentObjectId}) return s`, {
                parentObjectId: parentObjectId
            });
    }

    public static deleteSensorByObjectId(dbContext: DbContext, objectId: string) {
        return dbContext.callExtension("runQuery",
            `match (s:Sensor {objectId: $objectId}) detach delete s`, {
                objectId: objectId
            })
    }

    public static deleteThingByObjectId(dbContext: DbContext, objectId: string) {
        return dbContext.callExtension("runQuery",
            `match (t:Thing {objectId: $objectId})-[r]->(:Room),
                (t2:Thing {objectId: $objectId}) delete r,t,t2`, {
                objectId: objectId
            });
    }

    public static getAllSensors(dbContext: DbContext) {
        return dbContext.callExtension("runQuery",
            `match (s:Sensor) return s`);
    }

    public static getSensorsByAp(dbContext: DbContext, ontologyNodes) {
        let query = ""
        let variables = {}

        for (let i = 0; i < ontologyNodes.length; i++) {
            query += "match (s:Sensor)-[r]-(o:Ontology) where o.name = $variable" + i.toString()
            if (i != (ontologyNodes.length - 1)) {
                query += " with s ";
            } else {
                query += " return s";
            }
            variables["variable" + i.toString()] = ontologyNodes[i]
        }

        return dbContext.callExtension("runQuery", query, variables);
    }
}
