/**
* MIT License
*
* Copyright (c) 2020 fortiss GmbH
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in all
* copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
* 
* SPDX-License-Identifier: MIT
* @author Erkan Karabulut 
* @version 1.0
 * Includes common json operations
 */

/**
 * Common JSON operations
 */
export class JSONUtil {
    public static linearize(jsonObject: JSON) {
        let linearizedJson = {};
        for (let attribute in jsonObject) {
            // check type of the element
            if (typeof jsonObject[attribute] == "object") {
                // object means either an object {} or an array []
                // check if it is an array
                if (Array.isArray(jsonObject[attribute])) {
                    let arrayCounter = 1;
                    // iterate over the array elements
                    for (let element in jsonObject[attribute]) {
                        // array elements can be object as well
                        if (typeof jsonObject[attribute][element] == "object") {
                            // call recursively if it's an object
                            let linearizedInnerJson = this.linearize(jsonObject[attribute][element]);
                            // concat array elements with the linearized json
                            for (let element in linearizedInnerJson) {
                                linearizedJson[attribute + "_" + element] = linearizedInnerJson[element];
                            }
                        } else {
                            // use array index to concat array elements
                            linearizedJson[attribute + "_" + arrayCounter.toString()] = element;
                            arrayCounter++;
                        }
                    }
                } else {
                    // if not an array, then call recursively to get the elements inside
                    let linearizedInnerJson = this.linearize(jsonObject[attribute]);
                    for (let element in linearizedInnerJson) {
                        linearizedJson[attribute + "_" + element] = linearizedInnerJson[element];
                    }
                }
            } else {
                // if not an object then directly put it into linearized json
                linearizedJson[attribute] = jsonObject[attribute];
            }
        }

        return linearizedJson;
    }
}
